focusedPinTheme property
PinTheme?
focusedPinTheme
final
The pin input field theme for Pinput when a cell has focus.
Implementation
final PinTheme? focusedPinTheme;
The pin input field theme for Pinput when a cell has focus.
final PinTheme? focusedPinTheme;