StorageHelper class

Constructors

StorageHelper({required bool useSecure})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useSecure bool
final

Methods

getRecoveryCodes() Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBool(String key, {bool defaultValue = false}) Future<bool>
readString(String key) Future<String?>
saveRecoveryCodes(List<String> codes) Future<void>
toString() String
A string representation of this object.
inherited
useRecoveryCode(String code) Future<bool>
writeBool(String key, bool value) Future<void>
writeString(String key, String value) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited